# spanish.tcl:
# Spanish translations for Scid.

# Contributors:
# Jordi Gonzlez Boada
# Enrique Lopez
# Benigno Hernndez Bacallado
# Igor Sosa Mayor
# Dale J.H Cannon

# Untranslated messages are marked with a "TODO To be translated" comment.

addLanguage S Espaol 1 ;#iso8859-1

proc setLanguage_S {} {

# File menu:
menuText S File "Archivo" 0
menuText S FileNew "Nuevo..." 0 {Crea una nueva base de datos Scid vaca}
menuText S FileOpen "Abrir..." 1 {Abre una base de datos Scid ya existente}
menuText S FileClose "Cerrar" 0 {Cierra la base de datos Scid activa}
menuText S FileFinder "Visor..." 0 {Abre la ventana del visor de archivos}
menuText S FileSavePgn "Grabar PGN" 0 {Graba la partida a un fichero PGN}
menuText S FileOpenBaseAsTree "Abrir base como rbol" 0   {Abrir una base y usarla en la ventana de rbol (Tree)}
menuText S FileOpenRecentBaseAsTree "Abrir base reciente como rbol" 0   {Abre una base reciente y la usa en ventana de rbol (Tree)}
menuText S FileBookmarks "Partidas favoritas" 0 {Seleccionar partidas favoritas (Ctrl+B)}
menuText S FileBookmarksAdd "Aadir" 0 {Seala la partida y posicin actual de la base de datos}
menuText S FileBookmarksFile "Archivar" 8 {Archiva un marcador para la partida y posicin actual}
menuText S FileBookmarksEdit "Editar partidas favoritas..." 0 {Edita los menus de las partidas favoritas}
menuText S FileBookmarksList "Mostrar partidas favoritas" 0 {Muestrar las carpetas de favoritas en una sola lista, sin submens}
menuText S FileBookmarksSub "Mostrar partidas marcadas con submenus" 0 {Muestrar las carpetas de favoritas como submens, no una sola lista}
menuText S FileReadOnly "Slo lectura" 0 \
  {Trata la actual base de datos como de slo lectura, previniendo cambios}
menuText S FileSwitch "Cambiar de base" 0 \
  {Cambia a otra base de partidas abierta}
menuText S FileExit "Salir" 0 {Salir de Scid}

# Edit menu:
menuText S Edit "Editar" 0
menuText S EditAdd "Aadir variacin" 0 \
  {Aade una variacin a este movimiento en la partida}
menuText S EditPasteVar "Pegar Variacin" 0
menuText S EditDelete "Borrar variacin" 0 {Borra variacin para este movimiento}
menuText S EditDeleteComment "Borrar comentario" 0
menuText S EditFirst "Convertir en primera variacin" 0 \
  {Hace que una variacin sea la primera en la lista}
menuText S EditMain "Variacin a lnea principal" 0 \
   {Promover una variacin para que sea la lnea principal}
menuText S EditTrial "Probar variacin" 1 \
  {Inicia/para el modo de prueba, para ensayar una idea en el tablero}
menuText S EditStrip "Eliminar" 2 \
  {Eliminar comentarios o variaciones de esta partida}
menuText S EditUndo "Deshacer" 0 {Deshace el ltimo cambio en la partida}
menuText S EditRedo "Rehacer" 0
menuText S EditStripComments "Comentarios" 0 \
  {Quita todos los comentarios y variaciones de esta partida}
menuText S EditStripVars "Variaciones" 0 {Quita todas las variaciones de esta partida}
menuText S EditStripBegin "Movimientos desde el principio" 1 \
  {Quita los movimientos desde el principio de la partida}
menuText S EditStripEnd "Movimientos hasta el final" 0 \
  {Quita los movimientos hasta el final de la partida}
menuText S EditReset "Poner a cero la base de trabajo" 0 \
  {Pone a cero la base de trabajo (clipbase) para que est completamente vaca}
# Benigno
menuText S EditCopy "Copiar partida a Clipbase" 1 \
  {Copia esta partida a Clipbase}
# Benigno
menuText S EditPaste "Pegar ltima partida de Clipbase" 2 \
  {Pega la ltima partida de la Clipbase aqu}

# Benigno
menuText S EditPastePGN "Pegar texto como partida PGN..." 10 \
  {Interpreta el texto del portapapeles como una partida en notacion PGN y la pega aqu}

# Benigno
menuText S EditSetup "Editar posicin..." 26 \
  {Inicia el tablero de posicin con la posicin de la partida}

menuText S EditCopyBoard "Copiar posicin" 8 \
  {Copia el tablero actual en notacin FEN a la seleccin de texto (clipboard)}
# Benigno
menuText S EditCopyPGN "Copiar partida PGN" 0 {}

# Benigno
menuText S EditPasteBoard "Pegar posicin" 6 \
  {Coloca el tablero inicial de la seleccin de texto actual (clipboard)}

# Game menu:
menuText S Game "Partida" 0
menuText S GameNew "Partida nueva" 0 \
  {Vuelve a una partida nueva, descartando cualquier cambio}
menuText S GameFirst "Cargar primera" 5 {Carga la primera partida filtrada}
menuText S GamePrev "Cargar anterior" 5 {Carga la anterior partida filtrada}
menuText S GameReload "Recarga partida" 2 \
  {Recargar esta partida, descartando cualquier cambio hecho}
menuText S GameNext "Cargar siguiente" 7 {Carga la siguiente partida filtrada}
menuText S GameLast "Cargar ltima" 8 {Carga la ltima partida filtrada}
menuText S GameRandom "Cargar partida aleatoria" 8 {Carga aleatoriamente una partida filtrada}
menuText S GameNumber "Cargar partida nmero" 5 \
  {Carga una partida poniendo su nmero}
menuText S GameReplace "Reemplazar partida" 6 \
  {Guarda esta partida, reemplazando la antigua versin}
menuText S GameAdd "Aadir partida" 0 \
  {Guarda esta partida como una nueva partida en la base de datos}
menuText S GameInfo "Informacin de la partida" 0
menuText S GameBrowse "Examinar partidas" 0
menuText S GameList "Listar todas las partidas" 0
menuText S GameDelete "Borrar partida" 0
menuText S GameDeepest "Identificar apertura" 0 \
  {Va a la posicin ms avanzada de la partida segn el libro ECO}
menuText S GameGotoMove "Ir al movimiento nmero" 5 \
  {Ir al nmero de movimiento especificado en la partida actual}
menuText S GameNovelty "Encontrar novedad" 7 \
  {Encuentra el primer movimiento de esta partida que no se ha jugado antes}

# Search Menu:
menuText S Search "Buscar" 0

# Benigno
menuText S SearchReset "Reiniciar el filtro" 0 \
  {Eliminar el filtro para que todas la partidas estn incluidas}

menuText S SearchNegate "Invertir filtro" 0 {Invierte el filtro para slo incluir las partidas excluidas}
menuText S SearchEnd "Mover a ltimo filtro" 0
menuText S SearchCurrent "Tablero actual..." 0 \
  {Busca por la posicin actual del tablero}
menuText S SearchHeader "Encabezamiento..." 0 \
  {Busca por informacin de encabezamiento (jugador, evento, etc)}
menuText S SearchMaterial "Material/Patrn..." 0 \
  {Busca por material o patrn del tablero}
menuText S SearchMoves {Jugadas} 0 {}
menuText S SearchUsing "Cargar archivo de bsqueda" 0 \
  {Busca usando un archivo de opciones de bsqueda}

# Windows menu:
menuText S Windows "Ventanas" 0
menuText S WindowsGameinfo "Mostrar informacin de la partida" 0 {Muestra la informacin de la partida}
menuText S WindowsComment "Editor de comentarios" 0 \
  {Abre/cierra el editor de comentarios}
menuText S WindowsGList "Listado de partidas" 0 \
  {Abre/cierra la  ventana de listado de partidas}
menuText S WindowsPGN "Ventana PGN" 8 {Abre/cierra la ventana de PGN (notacin de partida)}
menuText S WindowsCross "Tabla cruzada" 0 {Muestra la tabla cruzada para esta partida}
menuText S WindowsPList "Buscador de jugadores" 2 {Abre/cierra el buscador de jugadores}
menuText S WindowsTmt "Visor de torneos" 9 {Abre/cierra el visor de torneos}
menuText S WindowsSwitcher "Intercambiador de bases de datos" 0 \
  {Abre/cierra la ventana del intercambiador de bases de datos}
menuText S WindowsMaint "Mantenimiento" 11 \
  {Abre/cierra la ventana de mantenimiento}
menuText S WindowsECO "Buscador ECO" 0 {Abre/cierra la ventana del buscador ECO}
menuText S WindowsStats "Estadsticas" 12 \
  {Abre/cierra la ventana de estadsticas del filtro}
menuText S WindowsTree "rbol de Aperturas" 6 {Abre/cierra la ventana de rbol de Aperturas (Book)}
menuText S WindowsTB "Tablas de  Finales (TBs)" 8 \
  {Abre/cierra la ventana de TBs}
menuText S WindowsBook "Libros de aperturas (Book)" 0 {Abrir/Cerrar la ventana de libros de aperturas (Book)}
menuText S WindowsCorrChess "Correo electrnico" 0 {Abrir/Cerrar la ventra de correo}

# Tools menu:
menuText S Tools "Herramientas" 0
menuText S ToolsAnalysis "Motor de anlisis..." 0 \
  {Inicia/para el anlisis de un motor de ajedrez}
menuText S ToolsEmail "Administrador de email" 0 \
  {Abre/cierra la ventana del administrador de email}
menuText S ToolsFilterGraph "Filtro grfico" 7 \
  {Abre/cierra la ventana del filtro grfico}
menuText S ToolsAbsFilterGraph "Filtro grfico Abs." 7 {Abrir/Cerrar la ventana de filtro grfico para valores absolutos}
menuText S ToolsOpReport "Informe de la apertura" 1 \
  {Crea un informe de la apertura para la posicin actual}
menuText S ToolsTracker "Rastreador de piezas"  6 {Abre la ventana del rastreador de piezas}
menuText S ToolsTraining "Entrenamiento"  0 {Entrenamiento (tctica, aperturas,...)}
menuText S ToolsComp "Torneo de motores" 0 {Torneo de motores}
menuText S ToolsTacticalGame "Computadora - Phalanx"  0 {Jugar una partida tctica}
menuText S ToolsSeriousGame "Computadora - Motor UCI"  0 {Jugar contra un motor UCI}
menuText S ToolsTrainTactics "Mate en ..N.. (puzzles)"  0 {Resover problemas de "Mate en"}
menuText S ToolsTrainCalvar "Clculo de variaciones"  0 {Calculo de variantes}
menuText S ToolsTrainFindBestMove "Encontrar la mejor jugada"  0 {Busca el movimiento mejor}
menuText S ToolsTrainFics "Internet (FICS)"  0 {Jugar en freechess.org}
menuText S ToolsBookTuning "Sintonizar libro de aperturas" 0 {Sintonizar libro (Book)}
menuText S ToolsMaint "Mantenimiento" 0 \
  {Herramientas de mantenimiento de la base de datos Scid}
menuText S ToolsMaintWin "Mantenimiento" 0 \
  {Abre/cierra la ventana de mantenimiento de la base de datos Scid}
menuText S ToolsMaintExtra "Etiquetas extra" 0 {Etiquetas extra}
menuText S ToolsMaintCompact "Compactar base de datos..." 0 \
  {Compacta los archivos de la base de datos, quitando partidas borradas y nombres no usados}
menuText S ToolsMaintClass "Clasificar partidas por ECO..." 24 \
  {Recalcula el cdigo ECO de todas las partidas}
menuText S ToolsMaintSort "Ordenar base de datos..." 0 \
  {Ordena todas las partidas de la base de datos}
menuText S ToolsMaintDelete "Borrar partidas dobles..." 0 \
  {Encuentra partidas dobles y las coloca para ser borradas}
menuText S ToolsMaintTwin "Inspeccin de dobles" 11 \
  {Abre/actualiza la ventana de inspeccin de dobles}
menuText S ToolsMaintNameEditor "Edicin de nombres" 0 \
  {Abre/Cierra la ventana de edicin de nombres}
menuText S ToolsMaintNamePlayer "Correccin de nombres de jugadores" 11 \
  {Comprobacin ortogrfica de jugadores usando archivo de comprobacin ortogrfica}
menuText S ToolsMaintNameEvent "Correccin de nombres de eventos" 11 \
  {Comprobacin ortogrfica de eventos usando el archivo de comprobacin ortogrfica}
menuText S ToolsMaintNameSite "Correccin de nombres de lugares" 11 \
  {Comprobacin ortogrfica de lugares usando el archivo de comprobacin ortogrfica}
menuText S ToolsMaintNameRound "Correccin de nombre de rondas" 11 \
  {Comprobacin ortogrfica de rondas usando el archivo de comprobacin ortogrfica}
menuText S ToolsMaintFixBase "Reparar base corrupta" 0 {Intenta reparar una base corrupta}
menuText S ToolsConnectHardware "Conectar hardware" 0 {Conectar  hardware externo}
menuText S ToolsConnectHardwareConfigure "Configurar..." 0 {Configurar conexin a hardware externo}
menuText S ToolsConnectHardwareNovagCitrineConnect "Conectar Novag Citrine" 0 {Conectar Novag Citrine}
menuText S ToolsConnectHardwareInputEngineConnect "Conectar Tablero" 0 {Conectar tablero de entra (p.ej. DGT)}
menuText S ToolsPInfo "Informacin del jugador" 16 \
  {Abrir/actualizar la ventana de informacin del jugador}
menuText S ToolsPlayerReport "Informe del jugador" 3 \
  {Crea un informe sobre un jugador}
menuText S ToolsRating "Rating del jugador" 0 \
  {Grfico de la historia del Elo de los jugadores de la actual partida}
menuText S ToolsScore "Grfico de puntuacin" 1 \
  {Muestra la ventana del grfico de puntuacin}
menuText S ToolsExpCurrent "Exportar la partida actual" 0 \
  {Escribe la partida actual en un archivo de texto}
menuText S ToolsExpCurrentPGN "Exportar Partida a PGN" 15 \
  {Escribe la partida actual en un archivo PGN}
menuText S ToolsExpCurrentHTML "Exportar Partida a HTML" 15 \
  {Escribe la partida actual en un archivo HTML}
menuText S ToolsExpCurrentHTMLJS "Exportar Partida a HTML y JavaScript" 15 {Escribir partida actual a un fichero HTML y JavaScript}
menuText S ToolsExpCurrentLaTeX "Exportar Partida a LaTeX" 33 \
  {Escribe la partida actual en un archivo LaTeX}
menuText S ToolsExpFilter "Exportar todas las partidas filtradas" 1 \
  {Escribe todas las partidas filtradas en un archivo de texto}
menuText S ToolsExpFilterPGN "Exportar filtro a PGN" 17 \
  {Escribe todas las partidas filtradas en un archivo PGN}
menuText S ToolsExpFilterHTML "Exportar filtro a HTML" 17 \
  {Escribe todas las partidas filtradas en un archivo HTML}
menuText S ToolsExpFilterHTMLJS "Exportar filtro a HTML y JavaScript" 17 {Escribir todas las partidas filtradas a fichero HTML y JavaScript}
menuText S ToolsExpFilterLaTeX "Exportar filtro a LaTeX" 17 \
  {Escribe todas las partidas filtradas en un archivo LaTeX}
menuText S ToolsExpFilterEPD "Exportar filtro a EPD/FEN" 17 {Guarda todos los juegos filtrados en un archivo EPD}
menuText S ToolsExpFilterGames "Exportar Listado a Texto" 19 {Imprime un listado del juego formateado.}
menuText S ToolsImportOne "Importar partida PGN" 0 \
  {Importa una partida de un texto PGN}
menuText S ToolsImportFile "Importar archivo de partidas PGN" 2 \
  {Importa partidas de un archivo PGN}
menuText S ToolsStartEngine1 "Iniciar motor 1" 0  {Iniciar motor 1}
menuText S ToolsStartEngine2 "Iniciar motor 2" 0  {Iniciar Motor 2}
menuText S ToolsScreenshot "Captura de pantalla" 0
menuText S Play "Jugar" 0
menuText S CorrespondenceChess "Ajedrez por correo" 0 \
  {Funciones para ajedrez por correo basado en email y Xfcc}
menuText S CCConfigure "Configurar..." 0 \
  {Configura herramientas externas y configuracin general}
menuText S CCConfigRelay "Configurar observaciones..." 10 {Configurar partidas para ser observadas}
menuText S CCOpenDB "Abrir base de datos..." 0 \
  {Abrir la base de correo por defecto}
menuText S CCRetrieve "Reparar partidas" 0 \
  {Repara partidas va ayuda externa (Xfcc)}
menuText S CCInbox "Procesar correo entrante" 0 \
  {Procesa todos los ficheros en correo entrante de Scid (Inbox)}
menuText S CCSend "Enviar movimiento" 0 \
  {Enva tu movimiento via email o ayuda externa (Xfcc)}
menuText S CCResign "Abandonar" 0 {Abandona}
menuText S CCClaimDraw "Reclamar tablas" 0 \
  {Enva un movimiento y reclama tablas}
menuText S CCOfferDraw "Ofrecer tablas" 0 \
  {Enva un movimiento y ofrece tablas}
menuText S CCAcceptDraw "Aceptar tablas" 0 {Acepta un ofrecimiento de tablas}
menuText S CCNewMailGame "Nueva partida email..." 0 \
  {Empeza una nueva partida por email}
menuText S CCMailMove "Enviar jugada via email..." 0 \
  {Enva el movimiento via email al oponente}
menuText S CCGamePage "Pgina de la partida..." 0 \
  {Abre la partida desde el navegador}
menuText S CCEditCopy "Copiar lista de partidas a clipbase" 0 \
  {Copia las partidas como una lista CSV a Clipbase}


# Options menu:
menuText S Options "Opciones" 0
menuText S OptionsBoard "Tablero" 0 {Opciones sobre el aspecto del tablero}
menuText S OptionsColour "Color de fondo" 0 {Color de fondo por defecto}
menuText S OptionsBackColour "Fondo" 0 {Color del widget de texto predeterminado}
menuText S OptionsBackColourGlobal "Global" 0 {Color de fondo global}
menuText S OptionsMainLineColour "Flechas principales" 0 {Flechas principales}
menuText S OptionsVarLineColour "Flechas de variacin" 0 {Flechas de variacin}
menuText S OptionsEngineLineColour "Flechas del motor" 0 {Flechas del motor}
menuText S OptionsRowColour "Filas" 0 {Color predeterminado de la columna de rbol/libro}
menuText S OptionsHighlightColour "Resaltado" 0 {Color por defecto del texto resaltado}
menuText S OptionsSwitcherColour "Conmutador" 0 {Color del conmutador db predeterminado}
menuText S OptionsProgressColour "Barra de progreso" 0 {Color predeterminado de la barra de progreso}
menuText S OptionsScoreColour "Grfico de puntuacin" 0 {}
menuText S OptionsScoreBarColour "Grfico de puntuacin actual" 0 {}
menuText S OptionsNames "Mis Nombres de Jugador" 3 {Edita mis nombres de jugador}
menuText S OptionsExport "Exportacin" 0 {Cambia las opciones de exportacin de texto}
menuText S OptionsFonts "Fuentes" 0 {Cambia las fuentes}
menuText S OptionsFontsRegular "Habitual" 0 {Cambia la fuente habitual}
menuText S OptionsFontsMenu "Men" 0 {Cambia la fuente del men}
menuText S OptionsFontsSmall "Pequea" 0 {Cambia la fuente pequea}
menuText S OptionsFontsFixed "Fijada" 0 {Cambia la anchura fijada de la fuente}
menuText S OptionsEvalbar "Barra de evaluacin" 0 {Opciones de la barra de evaluacin}
menuText S OptionsGInfo "Informacin de la partida" 0 {Informacin de la partida}
menuText S OptionsFics "FICS" 0
menuText S OptionsFicsAuto "Autopromocin Reina" 0
menuText S OptionsFicsClk "Guarda los tiempos del reloj" 0
menuText S OptionsFicsColour "Color del texto" 0
menuText S OptionsFicsSize "Tamao del Tablero" 0
menuText S OptionsFicsButtons "Botones de usuario" 0
menuText S OptionsFicsCommands "Comandos iniciales" 0
menuText S OptionsFicsNoRes "Sin resultados" 0
menuText S OptionsFicsNoReq "Sin respuesta" 0
menuText S OptionsFicsPremove "Permitir Pre-movimiento" 0
menuText S OptionsEvalMain "Tablero principal" 0
menuText S OptionsEvalBrowser "Navegadores de juego" 0
menuText S OptionsEvalFics "Tableros Fics" 0
menuText S OptionsEvalTime "Tiempo de evaluacin" 0 {Tiempo para el anlisis rpido}
# ====== TODO To be translated ======
menuText S OptionsEvalScale "Scale" 0 {Scorebar scale}
# ====== TODO To be translated ======
menuText S OptionsEvalTicks "Show ticks" 0
menuText S OptionsEvalLog  "Evaluacin logartmica" 0
menuText S OptionsLanguage "Lenguaje" 0 {Selecciona el lenguaje del men}
menuText S OptionsMovesTranslatePieces "Traducir piezas" 0 {Traducir la primera letra de las piezas}
menuText S OptionsMovesHighlightLastMove "Resalta ltima jugada" 0 {Resalta la ltima jugada}
menuText S OptionsMovesHighlightLastMoveDisplay "Mostrar" 0 {Muestra la ltima jugada iluminada}
menuText S OptionsMovesHighlightLastMoveWidth "Ancho" 0 {Espesor de la lnea}
menuText S OptionsMovesHighlightLastMoveColor "Select Color" 0 {Color de lnea}
menuText S OptionsMovesColorSelected "Color de la casilla seleccionada" 0 {Color del movimiento}
menuText S OptionsMoves "Movimientos" 0 {Opciones de la entrada de movimientos}
menuText S OptionsMovesAsk "Preguntar antes de reemplazar movimientos" 0 \
  {Pregunta antes de sobreescribir cualquier movimiento existente}
menuText S OptionsMovesAnimate "Velocidad de la animacin" 1 \
  {Pone el tiempo usado para animar las jugadas}
menuText S OptionsMovesDelay "Retardo del Automovimiento" 1 \
  {Pone el tiempo de demora para el modo de automovimiento}
menuText S OptionsMovesCoord "Entrada de movimientos coordinada" 0 \
  {Acepta entrada de movimientos en sistema "coordinado" ("g1f3")}
menuText S OptionsMovesSuggest "Mostrar movimientos sugeridos" 0 {Activa o desactiva la sugerencia de movimientos}
menuText S OptionsShowVarPopup "Mostrar ventana de variaciones" 0 {Activa/desactivar la ventana de variaciones}
menuText S OptionsMovesSpace "Aadir espacios detrs de nmero de jugada" 0 {Aadir espacios detrs del nmero de jugada}
menuText S OptionsMovesKey "Teclado inteligente" 0 \
{Activa/desactiva la funcin de autocompletado inteligente de movimientos con teclado}
menuText S OptionsMovesShowVarArrows "Mostrar flechas para las variaciones" 0 \
  {Activa/desactiva mostrar flechas para las variaciones}
menuText S OptionsNumbers "Formato de nmeros" 11 {Selecciona el formato de nmeros}
menuText S OptionsStartup "Inicio" 3 {Seleccionar ventanas a abrir al inicio}
menuText S OptionsTheme "Tema" 0 {Cambia el aspecto del interfaz}
menuText S OptionsWindows "Ventanas" 0 {Opciones de ventana}
menuText S OptionsWindowsIconify "Autominimizar" 4 \
  {Minimiza todas las ventanas cuando la ventana principal es minimizada}
menuText S OptionsWindowsRaise "Poner a la vista automticamente" 0 \
  {Hace visibles ciertas ventanas (ej. barras de progreso) siempre que estn tapadas}
menuText S OptionsSounds "Sonidos" 2 {Configura el sonido del anuncio de las jugadas}
menuText S OptionsWindowsDock "Ventanas en dique" 0 {Ventanas en dique}
menuText S OptionsWindowsSaveLayout "Salvar disposicin" 0 {Salva la disposicin}
menuText S OptionsWindowsRestoreLayout "Restaurar disposicin" 0 \
  {Restaura la disposicin}
menuText S OptionsWindowsShowGameInfo "Mostrar informacin de la partida" 0 \
  {Muestrar informacin de la partida}
menuText S OptionsWindowsAutoLoadLayout "Autocargar primera disposicin" 0 \
  {Autocarga la primera disposicin al iniciar}
menuText S OptionsWindowsAutoResize "Ajustar tablero automticamente" 0 {}
menuText S OptionsWindowsFullScreen "Pantalla completa" 0 {Activa la pantalla completa}
menuText S OptionsToolbar "Barra de Herramientas" 9 \
  {Muestra/oculta la barra de herramientas de la ventana principal}
menuText S OptionsECO "Cargar archivo ECO" 7 \
  {Cargar el archivo de clasificacin ECO}
menuText S OptionsSpell "Cargar archivo de comprobacin ortogrfica" 11 \
  {Carga el archivo de comprobacin ortogrfica Scid}
menuText S OptionsTable "Directorio de Tablas de Finales" 10 \
  {Selecciona el directorio de finales; todas las TB de ese directorio sern usadas}
menuText S OptionsRecent "Archivos recientes" 0 \
  {Cambia el nmero de archivos recientes mostrados en el men Archivo}
menuText S OptionsBooksDir "Carpeta de libros de Aperturas (Books)" 0 {Fija la carpeta de los libros de aperturas (Books)}
menuText S OptionsTacticsBasesDir "Carpeta de bases" 0 {Fija la carpeta de la base de entrenamiento tctico}
menuText S OptionsInformant "Configurar valores de informacin" 0
menuText S OptionsSave "Guardar opciones" 0 \
  "Guarda todas las opciones en el fichero $::optionsFile"

menuText S OptionsSaveBases "Guardar bases por defecto" 0

menuText S OptionsAutoSave "Autoguardar opciones al salir" 0 \
  {Guarda automticamente todas las opciones cuando se sale de Scid}

# Help menu:
menuText S Help "Ayuda" 1
menuText S HelpContents "Contenidos" 0 {Show the help contents page}
menuText S HelpIndex "Indice" 0 {Muestra la pgina ndice de la ayuda}
menuText S HelpGuide "Gua rpida" 0 {Muestra la pgina de la ayuda gua rpida}
menuText S HelpHints "Sugerencias" 1 {Muestra la pgina de la ayuda sugerencias}
menuText S HelpContact "Informacin de contacto" 15 \
  {Muestra la pgina de la ayuda de la informacin de contacto}
menuText S HelpTip "Sugerencia del da" 0 {Muestra una sugerencia para el uso de Scid}
menuText S HelpStartup "Ventana de inicio" 0 {Muestra la ventana de inicio}
menuText S HelpAbout "Acerca de Scid" 10 {Informacin acerca de Scid}

# Game info box popup menu:
menuText S GInfoHideNext "Ocultar siguiente movimiento" 0
menuText S GInfoShow "Lado a jugar" 0
menuText S GInfoCoords "Coordenadas" 0
menuText S GInfoMaterial "Mostrar valor del material" 0
menuText S GInfoFEN "Mostrar FEN" 8
menuText S GInfoMarks "Mostrar casillas y flechas coloreadas" 29
menuText S GInfoWrap "Dividir lneas largas" 0
menuText S GInfoFullComment "Mostrar comentarios completos" 8
menuText S GInfoPhotos "Mostrar fotos" 5
menuText S GInfoTBNothing "TBs: nada" 5
menuText S GInfoTBResult  "TBs: slo resultado" 10
menuText S GInfoTBAll "TBs: resultado y mejor movimiento" 23
menuText S GInfoDelete "(No)Borrar esta partida" 4
menuText S GInfoMark "(No)Marcar esta partida" 4
menuText S GInfoMenuBar "Barra de Mens"  0
menuText S GInfoToolBar "Barra de Herramientas"  0
menuText S GInfoButtonBar "Botn de Barra"  0
menuText S GInfoStatusBar "Barra de Estado"  0
menuText S GInfoEvalBar "Barra de evaluacin" 0

translate S FlipBoard {Girar el tablero}
translate S RaiseWindows {Aumentar ventanas}
translate S AutoPlay {Reproduccin automtica}
translate S TrialMode {Modo de prueba}

translate S KeepOpen {Mantener abierto despus del inicio}

# General buttons:
translate S Apply {Aplicar}
translate S Back {Atrs}
translate S Browse {Examinar}
translate S Cancel {Cancelar}
translate S Continue {Continuar}
translate S Clear {Limpiar}
translate S Close {Cerrar}
translate S Contents {Contenidos}
translate S Defaults {Por defecto}
translate S Delete {Borrar}
translate S Graph {Grfico}
translate S Help {Ayuda}
translate S Import {Importar}
translate S Index {ndice}
translate S LoadGame {Cargar}
translate S BrowseGame {Examinar}
translate S MergeGame {Mezclar o fundir}
translate S MergeGames {Mezclar o fusionar partidas}
translate S Preview {Vista previa}
translate S Revert {Retroceder}
translate S Save {Guardar}
translate S DontSave {No guardar}
translate S Search {Buscar}
translate S Stop {Parar}
translate S Store {Almacenar}
translate S Update {Actualizar}
translate S ChangeOrient {Cambiar orientacin de la ventana}
translate S ShowIcons {Mostrar iconos}
translate S ConfirmCopy {Confirmar Copia}
translate S None {Ninguno}
translate S First {Primera}
translate S Current {Actual}
translate S Last {ltima}
translate S Font {Fuente}
translate S Change {Cambiar}
translate S Random {Aleatorio}

# General messages:
translate S game {partida}
translate S games {partidas}
translate S move {movimiento}
translate S moves {movimientos}
translate S all {todo}
translate S Yes {S}
translate S No {No}
translate S Both {Ambos}
translate S King {Rey}
translate S Queen {Dama}
translate S Rook {Torre}
translate S Bishop {Alfil}
translate S Knight {Caballo}
translate S Pawn {Pen}
translate S White {Blancas}
translate S Black {Negras}
translate S Player {Jugador}
translate S Rating {Elo}
translate S RatingDiff {Diferencia de Elo (Blancas - Negras)}
translate S AverageRating {Elo promedio}
translate S Event {Evento}
translate S Site {Lugar}
translate S Country {Pas}
translate S IgnoreColors {Ignorar colores}
translate S MatchEnd {Posicin final}
translate S Date {Fecha}
translate S EventDate {Evento fecha}
translate S Decade {Dcada}
translate S Year {Ao}
translate S Month {Mes}
translate S Months {enero febrero marzo abril mayo junio julio agosto septiembre octubre noviembre diciembre}
translate S Days {dom lun mar mi jue vie sb}
translate S YearToToday {ltimo ao hasta hoy}
translate S Result {Resultado}
translate S Round {Ronda}
translate S Length {Longitud}
translate S ECOCode {Cdigo ECO}
translate S ECO {ECO}
translate S Deleted {Borrar}
translate S SearchResults {Buscar resultados}
translate S OpeningTheDatabase {Abriendo base de datos}
translate S Database {Base de datos}
translate S Filter {Filtro}
translate S Reset {Reiniciar}
translate S IgnoreCase {Ignorar el Asunto}
translate S noGames {No hay partidas}
translate S allGames {Todas las partidas}
translate S empty {vaca}
translate S clipbase {clipbase}
translate S score {puntuacin}
translate S Start {Principio}
translate S StartPos {Posicin inicial}
translate S Total {Total}
translate S readonly {slo lectura}
translate S altered {alterado}
translate S tagsDescript {Etiquetas adicionales (p.e.: Annotator "Anand")}
translate S prevTags {Usar el anterior}
translate S value {Valor}

# Standard error messages:
translate S ErrNotOpen {Esta base de datos no est abierta.}
translate S ErrReadOnly {Esta base de datos es de slo lectura; no puede ser cambiada.}
translate S ErrSearchInterrupted {La bsqueda se interrumpi; los resultados son incompletos.}

# Game information:
translate S twin {doble}
translate S deleted {borradas}
translate S comment {comentario}
translate S hidden {oculto}
translate S LastMove {ltimo movimiento}
translate S NextMove {Siguiente}
translate S GameStart {Inicio de partida}
translate S LineStart {Inicio de lnea}
translate S GameEnd {Fin de partida}
translate S LineEnd {Fin de lnea}

# Player information:
translate S PInfoAll {Todas las partidas}
translate S PInfoFilter {Las partidas filtradas}
translate S PInfoAgainst {Resultados contra}
translate S PInfoMostWhite {Aperturas ms comunes con Blancas}
translate S PInfoMostBlack {Aperturas ms comunes con Negras}
translate S PInfoRating {Historial de clasificacin}
translate S PInfoBio {Biografa}
translate S PInfoEditRatings {Editar ELOs}
translate S PinfoEditName {Editar nombre}
translate S PinfoLookupName {Buscar nombre}

# Tablebase information:
translate S Draw {Tablas}
translate S stalemate {rey ahogado}
translate S checkmate {mate}
translate S withAllMoves {con todos los movimientos}
translate S withAllButOneMove {con todos los movimientos excepto uno}
translate S with {con}
translate S only {slo}
translate S lose {formas de perder}
translate S loses {hace perder}
translate S allOthersLose {todos los dems hacen perder}
translate S matesIn {mate en}
translate S longest {el mate ms largo}
translate S WinningMoves {Movimientos ganadores}
translate S DrawingMoves {Movimientos para tablas}
translate S LosingMoves {Movimientos perdedores}
translate S UnknownMoves {Movimientos de resultado desconocido}

# Tip of the day:
translate S Tip {Sugerencia}
translate S TipAtStartup {Sugerencia al iniciar}

# Tree window menus:
menuText S TreeFile "Archivo" 0
menuText S TreeFileFillWithBase "Rellenar cach con base" 0 \
  {Rellena el archivo cach con todas las partidas de la base actual}
menuText S TreeFileFillWithGame "Rellenar cach con partida" 0 \
  {Rellena el fichero cach con movimientos de la partida actual en la base actual}
menuText S TreeFileCacheInfo "Informacin de cach" 0 \
  {Informacin y uso del cach}
menuText S TreeFileSave "Guardar archivo cach" 0 \
  {Guarda el archivo cach del rbol (.stc)}
menuText S TreeFileFill "Construir archivo cach" 2 \
  {Construye archivo cach con posiciones de apertura comunes}
menuText S TreeFileBest "Lista de mejores partidas" 9 \
  {Muestra la lista del rbol de mejores partidas}
menuText S TreeFileGraph "Grfico" 0 \
  {Muestra el grfico para esta rama del rbol}
menuText S TreeFileCopy "Copiar texto del rbol al portapapeles" 1 \
  {Copia texto del rbol al portapapeles}
menuText S TreeFileClose "Cerrar ventana del rbol" 0 \
  {Cerra ventana del rbol}
menuText S TreeMask "Mscara" 0
menuText S TreeMaskNew "Nuevo" 0 {Nueva mscara}
menuText S TreeMaskOpen "Abrir" 0 {Abre mscara}
menuText S TreeMaskOpenRecent "Abrir reciente" 0 {Abre mscara reciente}
menuText S TreeMaskSave "Salvar" 0 {Salva mscara}
menuText S TreeMaskClose "Cerrar" 0 {Cierra mscara}
menuText S TreeMaskFillWithLine "Llenar con lnea" 0 {Llena mscara con con todos los movimientos previos}
menuText S TreeMaskFillWithGame "Llenar con partida" 0 \
  {Llena mscara con partida}
menuText S TreeMaskFillWithBase "Llenar con base" 0 \
  {Llena mscara con todas las partidas de la base}
menuText S TreeMaskInfo "Info" 0 {Muestra estadsticas para la mscara actual}
menuText S TreeMaskDisplay "Mostrar mapa de la mscara" 0 \
  {Muestra mscara en forma de rbol}
menuText S TreeMaskSearch "Buscar" 0 {Busca en mscara actual}
menuText S TreeSort "Ordenar" 0
menuText S TreeSortAlpha "Alfabticamente" 0
menuText S TreeSortECO "Por cdigo ECO" 11
menuText S TreeSortFreq "Por frecuencia" 4
menuText S TreeSortScore "Por puntuacin" 4
menuText S TreeOpt "Opciones" 1
menuText S TreeOptSlowmode "Modo Lento" 0 \
  {Movimiento lento para actualizaciones (alta calidad)}
menuText S TreeOptFastmode "Modo Rpido" 0 \
  {Movimiento rpido para actualizaciones (no transpone movimientos)}
menuText S TreeOptFastAndSlowmode "Modo rpido y lento" 0 \
  {Movimiento rpido y modo lento para actualizaciones}
menuText S TreeOptStartStop "Auto actualizado" 0 \
  {Actualizado automtico de la ventana del rbol}
menuText S TreeOptLock "Bloquear" 1 \
  {Bloquea/desbloquea el rbol de la base de datos actual}
menuText S TreeOptTraining "Entrenamiento" 2 \
  {Activa/desactiva el modo de entrenamiento de rbol}
menuText S TreeOptShort "Pantalla corta" 0 {No mostrar informacin de ELO}
menuText S TreeOptAutosave "Autoguardar archivo cach" 0 \
  {Guarda automticamente el archivo cach cuando se cierra la ventana de rbol}
menuText S TreeOptAutomask "Carga automtica de mscara" 0 "Carga automtica de mscara con un arbol abierto."
menuText S TreeOptCacheSize "Tamao de cach" 0 {Fija el tamao del cach}
menuText S TreeOptShowBar "Mostrar barra de progreso" 0 "Mostrar barra de progreso del rbol"
menuText S TreeOptShowFrame "Mostrar barra de botones" 0 "Muestra la barra de botones."
menuText S TreeOptSmallFont "Usar fuente personalizada" 0 "Usa font_Small para el listado del juego."
menuText S TreeOptSortBest "Ordenar mejores partidas" 0 "Ordenar mejores partidas por ELO."
menuText S TreeHelp "Ayuda" 1
menuText S TreeHelpTree "Ayuda del rbol" 4
menuText S TreeHelpIndex "ndice de la ayuda" 0

translate S SaveCache {Guardar cach}
translate S Training {Entrenamiento}
translate S LockTree {Bloquear}
translate S TreeLocked {Bloqueado}
translate S TreeBest {Mejor}
translate S TreeBestGames {Mejores partidas del rbol}
translate S TreeAdjust {Ajustar filtro}
# Note: the next message is the tree window title row. After editing it,
# check the tree window to make sure it lines up with the actual columns.
translate S TreeTitleRow {    Movim.    Frecuencia   Puntu. Tablas AvElo Perf AvAo ECO}
translate S TreeTitleRowShort {    Movim.    Frecuencia   Puntu. Tablas}
translate S TreeTotal: {TOTAL:}
translate S DoYouWantToSaveFirst {Quieres salvar primero}
translate S AddToMask {Aadir a mscara}
translate S RemoveFromMask {Elimina desde la mscara}
translate S AddThisMoveToMask {Aadir este movimiento a la mscara}
translate S SearchMask {Buscar en mscara}
translate S DisplayMask {Mostrar mscara}
translate S MaskShowMarkers "Mostrar marcadores"
translate S MaskShowToolTips {Mostrar ayudas}
translate S Nag {Cdigo de regao}
translate S Marker {Marcador}
translate S Include {Incluir}
translate S Exclude {Excluir}
translate S MainLine {Lnea principal}
translate S Bookmark {Favorito}
translate S NewLine {Lnea nueva}
translate S ToBeVerified {Para ser verificado}
translate S ToTrain {Para entrenar}
translate S Dubious {Dudoso}
translate S ToRemove {Para quitar}
translate S NoMarker {Sin marcador}
translate S ColorMarker {Color}
translate S WhiteMark {Blanco}
translate S GreenMark {Verde}
translate S YellowMark {Amarillo}
translate S BlueMark {Azul}
translate S RedMark {Rojo}
translate S CommentMove {Comentar movimiento}
translate S CommentPosition {Comentar posicin}
translate S AddMoveToMaskFirst {Aadir primero el movimiento a la mscara}
translate S OpenAMaskFileFirst {Abrir primero un fichero de mscara}
translate S positions {posiciones}
translate S Moves {Jugadas}

# Finder window:
menuText S FinderFile "Archivo" 0
menuText S FinderFileSubdirs "Mirar en subdirectorios" 0
menuText S FinderFileClose "Cierra visor de archivos" 0
menuText S FinderSort "Ordenar" 0
menuText S FinderSortType "Tipo" 0
menuText S FinderSortSize "Tamao" 0
menuText S FinderSortMod "Modificado" 0
menuText S FinderSortName "Nombre" 0
menuText S FinderSortPath "Camino" 0
menuText S FinderTypes "Tipos" 0
menuText S FinderTypesScid "Bases de datos Scid" 0
menuText S FinderTypesOld "Bases de datos Scid en antiguo formato" 12
menuText S FinderTypesPGN "Archivos PGN" 9
menuText S FinderTypesEPD "Archivos EPD (libro)" 0
menuText S FinderHelp "Ayuda" 1
menuText S FinderHelpFinder "Ayuda del visor de archivos" 0
menuText S FinderHelpIndex "Indice de la ayuda" 0
translate S FileFinder {Visor de Archivos}
translate S FinderDir {Directorio}
translate S FinderDirs {Directorios}
translate S FinderFiles {Archivos}
translate S FinderUpDir {arriba}
translate S FinderCtxOpen {Abrir}
translate S FinderCtxBackup {Copia de seguridad (Backup)}
translate S FinderCtxCopy {Copia}
translate S FinderCtxMove {Jugada}
translate S FinderCtxDelete {Borrar}
translate S FinderCtxRename {Renombra}
translate S FinderDirOpen {Abrir directorio}

# Player finder:
menuText S PListFile "Archivo" 0
menuText S PListFileUpdate "Actualizar" 0
menuText S PListFileClose "Cierra el buscador de jugadores" 0
menuText S PListSort "Ordenar" 0
menuText S PListSortName "Nombre" 0
menuText S PListSortElo "Elo" 0
menuText S PListSortGames "Partidas" 0
menuText S PListSortOldest "Ms antiguo" 10
menuText S PListSortNewest "Ms nuevo" 4
menuText S PListSortCountry "Pas" 0

# Tournament finder:
menuText S TmtFile "Archivo" 0
menuText S TmtFileUpdate "Actualizar" 0
menuText S TmtFileClose "Cierra el visor de torneos" 0
menuText S TmtSort "Ordenar" 0
menuText S TmtSortDate "Fecha" 0
menuText S TmtSortPlayers "Jugadores" 0
menuText S TmtSortGames "Partidas" 0
menuText S TmtSortElo "Elo" 0
menuText S TmtSortSite "Lugar" 0
menuText S TmtSortEvent "Evento" 1
menuText S TmtSortWinner "Ganador" 0
translate S TmtLimit "Lmite de lista"
translate S TmtMeanElo "Media de Elo inferior"
translate S TmtNone "No se han encontrado torneos concordantes."

# Graph windows:
menuText S GraphFile "Archivo" 0
menuText S GraphFileColor "Guardar como postscript (color)" 8
menuText S GraphFileGrey "Guardar como postscript (escala de grises)" 8
menuText S GraphFileClose "Cerrar ventana" 0
menuText S GraphOptions "Opciones" 0
menuText S GraphOptionsWhite "Blancas" 0
menuText S GraphOptionsBlack "Negras" 0
menuText S GraphOptionsDots "Mostrar puntos" 0
# ====== TODO To be translated ======
menuText S GraphOptionsSpelling "Elo from Spelling File" 0
menuText S GraphOptionsBar "Destacar movimiento actual" 0
menuText S GraphOptionsBoth "Ambos" 0
menuText S GraphOptionsPInfo "Informacin jugador" 0
translate S GraphFilterTitle "Filtro grfico: frecuencia por 1000 partidas"
translate S GraphAbsFilterTitle "Filtro grfico: frecuencia de las partidas"
translate S ConfigureFilter {Configurar Eje-X para Ao, Rating y Movimientos}
translate S FilterEstimate "Estimar"
translate S TitleFilterGraph "Scid: filtro grfico"

# Analysis window:
translate S AddVariation {Aadir variacin}
translate S AddAllVariations {Aadir todas las variaciones}
translate S AddMove {Aadir movimiento}
translate S Annotate {Anotar}
translate S ShowAnalysisBoard {Mostrar tablero de anlisis}
translate S ShowInfo {Muestra info del motor}
translate S FinishGame {Finalizar partida}
translate S StopEngine {Parar motor}
translate S StartEngine {Iniciar motor}
translate S ExcludeMove {Excluir movimiento}
translate S LockEngine {Bloquea motor en posicin actual}
translate S AnalysisCommand {Direccin de anlisis}
translate S PreviousChoices {Eleccin previa}
translate S AnnotateTime {Segundos por movimiento}
translate S AnnotateWhich {Qu Lado?}
translate S AnnotateAll {Movimientos de ambos Lados}
translate S AnnotateAllMoves {Todos los movimientos}
translate S AnnotateWhite {Slo movimientos de las blancas}
translate S AnnotateBlack {Slo movimientos de las negras}
translate S AnnotateNotBest {Cuando el movimiento no es el mejor}
translate S AnnotateBlundersOnly {Cuando el movimiento es un disparate}
translate S BlundersNotBest {Fallo/No Mejor}
translate S AnnotateTitle {Configurar anotacin}
translate S AnnotateMissedMates {Mates omitidos/ms cortos}
translate S AnnotateEnd {Al final del juego}
translate S BlundersThreshold {(Umbral)}
translate S ScoreFormat {Formato de puntuacin}
translate S CutOff {Corte}
translate S LowPriority {Baja prioridad del procesador}
translate S LogEngines {Tamao del registro}
translate S LogName {Aadir nombre}
translate S MaxPly {Plies mximos}
translate S ClickHereToSeeMoves {Click aqu para ver movimientos}
translate S ConfigureInformant {Configurar informaciones}
translate S Informant!? {Movimiento interesante}
translate S Informant? {Movimiento malo}
translate S Informant?? {Desastroso}
translate S Informant?! {Movimiento dudoso}
translate S Informant+= {Blancas tienen una ligera ventaja}
translate S Informant+/- {Blancas tienen ventaja}
translate S Informant+- {Blancas tienen una ventaja decisiva}
translate S Informant++- {La partida es considerada ganada}
translate S Book {Libro}
translate S OtherBook {Otros movimientos}
translate S Alphabetical {Alfabtico}
translate S TwoBooks {Dos libros}

# Analysis Engine open dialog:
translate S EngineList {Lista de motores de anlisis}
translate S EngineKey {Tecla}
translate S EngineType {Protocolo}
translate S EngineName {Nombre}
translate S EngineCmd {Orden}
translate S EngineArgs {Parmetros}
translate S EngineDir {Directorio}
translate S EngineElo {Elo}
translate S EngineTime {Fecha}
translate S EngineNew {Nuevo}
translate S EngineEdit {Editar}
translate S EngineRequired {Los campos en negrita son obligatorios; los dems opcionales}

# Stats window menus:
menuText S StatsFile "Archivo" 0
menuText S StatsFilePrint "Imprimir en Archivo" 0
menuText S StatsFileClose "Cerrar ventana" 0
menuText S StatsOpt "Opciones" 0

# PGN window menus:
menuText S PgnFile "PGN" 0
menuText S PgnFileCopy "Copiar partida al portapapeles" 0
menuText S PgnFilePrint "Salvar partida como" 0
menuText S PgnFileClose "Cerrar" 10
menuText S PgnOpt "Opciones" 0
menuText S PgnOptColor "Color de la presentacin" 0
menuText S PgnOptShort "Ordenar Cabecera" 6
menuText S PgnOptSymbols "Anotaciones simblicas" 1
menuText S PgnOptIndentC "Sangra en comentarios" 0
menuText S PgnOptIndentV "Sangra en variaciones" 7
menuText S PgnOptColumn "Estilo de columna (un movimiento por lnea)" 1
menuText S PgnOptSpace "Espacio despus de nmeros de movimiento" 18
menuText S PgnOptStripMarks "Ocultar cdigos de casilla/flecha" 1
menuText S PgnOptChess "Piezas de ajedrez" 0
menuText S PgnOptScrollbar "Barra de desplazamiento" 0
menuText S PgnOptBoldMainLine "Lnea principal en negrita" 4
menuText S PgnColor "Colores" 1
menuText S PgnColorHeader "Encabezamiento..." 0
menuText S PgnColorAnno "Anotaciones..." 0
menuText S PgnColorComments "Comentarios..." 0
menuText S PgnColorVars "Variaciones..." 0
menuText S PgnColorBackground "Fondo..." 0
menuText S PgnColorMain "Lnea principal..." 0
menuText S PgnColorCurrent "Color de fondo del movimiento actual..." 1
menuText S PgnColorNextMove "Color de fondo del prximo movimiento..." 0
menuText S PgnHelp "Ayuda" 1
menuText S PgnHelpPgn "Ayuda de PGN" 9
menuText S PgnHelpIndex "Indice de la ayuda" 0
translate S PgnWindowTitle {Planilla - partida %u}

# Crosstable window menus:
menuText S CrosstabFile "Archivo" 0
menuText S CrosstabFileText "Salvar como texto" 8
menuText S CrosstabFileHtml "Salvar como HTML" 8
menuText S CrosstabFileLaTeX "Salvar como LaTeX" 8
menuText S CrosstabFileClose "Cerrar ventana de tabla cruzada" 0
menuText S CrosstabEdit "Editar" 0
menuText S CrosstabEditEvent "Evento" 0
menuText S CrosstabEditSite "Lugar" 0
menuText S CrosstabEditDate "Fecha" 0
menuText S CrosstabOpt "Opciones" 0
menuText S CrosstabOptColorPlain "Texto simple" 0
menuText S CrosstabOptColorHyper "Hipertexto" 0
menuText S CrosstabOptTieWin "Desempate por victorias" 1
menuText S CrosstabOptTieHead "Desempate por head-to-head" 1
menuText S CrosstabOptThreeWin "3 Puntos por victoria" 1
menuText S CrosstabOptAges "Edad en aos" 1
menuText S CrosstabOptNats "Nacionalidades" 0
menuText S CrosstabOptTallies "Ganadas/Perdidas/tablas" 0
menuText S CrosstabOptRatings "Elo" 0
menuText S CrosstabOptTitles "Ttulos" 0
menuText S CrosstabOptBreaks "Puntuaciones de desempate" 0
menuText S CrosstabOptDeleted "Incluir partidas borradas" 17
menuText S CrosstabOptColors "Colores (slo en tabla de Suizos)" 0
menuText S CrosstabOptColorRows "Filas de color" 0
menuText S CrosstabOptRowsColor "Filas de tabla cruzada" 0 {Color predeterminado de fila de tabla cruzada}
menuText S CrosstabOptColumnNumbers "Columnas numeradas (slo en tabla todos contra todos)" 11
menuText S CrosstabOptGroup "Grupos de clasificacin" 0
menuText S CrosstabSort "Ordenar" 0
menuText S CrosstabSortName "Por nombre" 4
menuText S CrosstabSortRating "Por Elo" 4
menuText S CrosstabSortScore "Por puntuacin" 4
menuText S CrosstabSortCountry "Pas" 4
menuText S CrosstabType "Sistema" 0
menuText S CrosstabTypeAll "Todos Contra Todos" 0
menuText S CrosstabTypeSwiss "Suizo" 0
menuText S CrosstabTypeKnockout "Rondas" 0
menuText S CrosstabTypeAuto "Auto" 0
menuText S CrosstabHelp "Ayuda" 1
menuText S CrosstabHelpCross "Ayuda de tabla cruzada" 9
menuText S CrosstabHelpIndex "Indice de la ayuda" 0
translate S SetFilter {Poner filtro}
translate S AddToFilter {Aadir al filtro}
translate S Swiss {Suizo}
translate S Category {Categora}

# Opening report window menus:
menuText S OprepFile "Archivo" 0
menuText S OprepFileText "Imprimir en texto" 9
menuText S OprepFileHtml "Imprimir en HTML..." 9
menuText S OprepFileLaTeX "Imprimir en LaTeX..." 9
menuText S OprepFileOptions "Opciones" 0
menuText S OprepFileClose "Cerrar ventana del informe de la apertura" 0
menuText S OprepFavorites "Favoritos" 1
menuText S OprepFavoritesAdd "Aadir informe" 0
menuText S OprepFavoritesEdit "Editar informe favorito" 0
menuText S OprepFavoritesGenerate "Generar informe" 0
menuText S OprepHelp "Ayuda" 1
menuText S OprepHelpReport "Ayuda del informe de la apertura" 11
menuText S OprepHelpIndex "ndice de la ayuda" 0

# Header search:
translate S HeaderSearch {Bsqueda por encabezamiento}
translate S EndSideToMove {Bando a mover al final de la partida}
translate S GamesWithNoECO {Partidas sin ECO?}
translate S GameLength {Duracin:}
translate S FindGamesWith {Encontrar partidas con}
translate S StdStart {Inicio estndar}
translate S Promotions {Promociones}
translate S UnderPromo {Bajo promocin}
translate S Comments {Comentarios}
translate S Variations {Variaciones}
translate S Annotations {Anotaciones}
translate S DeleteFlag {Seal de borrado}
translate S WhiteOpFlag {Apertura de las blancas}
translate S BlackOpFlag {Apertura de las negras}
translate S MiddlegameFlag {Mediojuego}
translate S EndgameFlag {Finales}
translate S NoveltyFlag {Novedad}
translate S PawnFlag {Estructura de peones}
translate S TacticsFlag {Tcticas}
translate S QsideFlag {Juego del lado de dama}
translate S KsideFlag {Juego del lado de rey}
translate S BrilliancyFlag {Genialidad}
translate S BlunderFlag {Error}
translate S UserFlag {Usuario}
translate S PgnContains {PGN contiene texto}
translate S PreComment {Comentario previo al juego}
translate S PostComment {Fin del comentario}

# Game list window:
translate S GlistNumber {Nmero}
translate S GlistWhite {Blancas}
translate S GlistBlack {Negras}
translate S GlistWElo {B-Elo}
translate S GlistBElo {N-Elo}
translate S GlistEvent {Evento}
translate S GlistSite {Lugar}
translate S GlistRound {Ronda}
translate S GlistDate {Fecha}
translate S GlistYear {Ao}
translate S GlistEventDate {Evento-Fecha}
translate S GlistResult {Resultado}
translate S GlistLength {Longitud}
translate S GlistCountry {Pas}
translate S GlistECO {ECO}
translate S GlistOpening {Movimientos}
translate S GlistEndMaterial {Material final}
translate S GlistDeleted {Borrado}
translate S GlistFlags {Seal}
translate S GlistVariations {Variaciones}
translate S GlistComments {Comentarios}
translate S GlistAnnos {Anotaciones}
translate S GlistStart {Inicio}
translate S GlistGameNumber {Nmero de partida}
translate S GlistFindText {Encontrar texto}
translate S GlistMoveField {Movimiento}
translate S GlistEditField {Configurar}
translate S GlistAddField {Aadir}
translate S GlistDeleteField {Borrar}
translate S GlistColor {Color}
translate S GlistSort {Ordenar base de datos}
translate S GlistRemoveThisGameFromFilter  {Oculta esta partida}
translate S GlistRemoveGameAndAboveFromFilter  {Oculta partidas por encima}
translate S GlistRemoveGameAndBelowFromFilter  {Oculta partidas por debajo}
translate S GlistDeleteGame {Elimina/Recupera esta partida de la base}
translate S GlistDeleteAllGames {Elimina todas las partidas de la base que aparecen en el filtro}
translate S GlistUndeleteAllGames {Recupera todas las partidas borradas de la base que aparecen en el filtro}
translate S GlistAlignL {Alinear a la izquierda}
translate S GlistAlignR {Alinear a la derecha}
translate S GlistAlignC {Alinear al centro}
translate S GlistMoveFieldUp {Mover arriba}
translate S GlistMoveFieldDown {Mover abajo}
translate S GlistMoveFieldFirst {Mover al principio}
translate S GlistMoveFieldLast {Mover al final}
translate S GlistMoveFieldN {Mover a N}

# Maintenance window:
translate S DatabaseName {Nombre de la base:}
translate S TypeIcon {Tipo de icono}
translate S NumOfGames {Partidas:}
translate S NumDeletedGames {Partidas borradas:}
translate S NumFilterGames {Partidas en el filtro:}
translate S YearRange {Rango de aos:}
translate S RatingRange {Rango de Elo:}
translate S Description {Descripcin}
translate S Flag {Seal}
translate S CustomFlags {Seales personalizadas}
translate S DeleteCurrent {Borrar partida actual}
translate S DeleteFilter {Borrar partidas filtradas}
translate S DeleteAll {Borrar todas las partidas}
translate S UndeleteCurrent {No borrar partida actual}
translate S UndeleteFilter {No borrar partidas filtradas}
translate S UndeleteAll {No borrar todas las partidas}
translate S DeleteTwins {Borrar partidas dobles}
translate S MarkCurrent {Marcar partida actual}
translate S MarkFilter {Marcar partidas filtradas}
translate S MarkAll {Marcar todas las partidas}
translate S UnmarkCurrent {No marcar partida actual}
translate S UnmarkFilter {No marcar partidas filtradas}
translate S UnmarkAll {No marcar todas las partidas}
translate S Spellchecking {Revisin ortogrfica}
translate S MakeCorrections {Hacer Correcciones}
translate S Ambiguous {Ambiguo}
translate S Surnames {Apellidos}
translate S Players {Jugadores}
translate S Events {Eventos}
translate S Sites {Lugares}
translate S Rounds {Rondas}
translate S DatabaseOps {Operaciones con la base de datos}
translate S ReclassifyGames {Reclasificar partidas por ECO...}
translate S CompactDatabase {Compactar base de datos}
translate S SortDatabase {Ordenar base de datos}
translate S AddEloRatings {Aadir clasificacin Elo}
translate S AutoloadGame {Autocargar partida}
translate S StripTags {Etiquetas extra}
translate S StripTag {Quitar etiquetas}
translate S AddTag {Aadir etiqueta}
translate S CheckGames {Revisar partidas}
translate S Cleaner {MultiHerramienta}
translate S CleanerHelp {
Scid ejecutar, en la actual base de datos, todas las acciones de mantenimiento que selecciones de la siguiente lista.

Se aplicar el estado actual en la clasificacin ECO y el dilogo de borrado de dobles si seleccionas esas funciones.
}
translate S CleanerConfirm {
Una vez que la MultiHerramienta de mantenimiento se inicia no puede ser interrumpida!

Esto puede tomar mucho tiempo en una base de datos grande, dependiendo de las funciones que hayas seleccionado y su estado actual.

Ests seguro de querer comenzar las funciones de mantenimiento que has seleccionado?
}
translate S TwinCheckUndelete {Pulsar "u" para no borrar ninguna (undelete)}
translate S TwinCheckprevPair {Pareja previa}
translate S TwinChecknextPair {Prxima Pareja}
translate S TwinChecker {Scid: Verificar partidas dobles}
translate S TwinCheckTournament {Partidas en torneo:}
translate S TwinCheckNoTwin {No doble  }
translate S TwinCheckNoTwinfound {No fueron detectados dobles para esta partida.\nto mostrar dobles usando esta ventana debes usar la funcin "Borrar partidas dobles" }
translate S TwinCheckTag {Compartir etiquetas...}
translate S TwinCheckFound1 {Scid encontr $result partidas dobles}
translate S TwinCheckFound2 {y pone pone sus banderas de borrado}
translate S TwinCheckNoDelete {No hay partidas en esta base para borrar.}
translate S TwinCriteria1 {Tus parmetros para encontrar partidas dobles potencialmente pueden causar partidas no-dobles con movimientos similares a ser marcadas como dobles.}
translate S TwinCriteria2 {Es recomendable que en caso de eligir  "No" para "algunos movimientos", se eleja "S"  para los parmetros colores, eventos, lugar, ronda, ao y mes.\nQuiere continuar y borrar partidas dobles en cualquier caso?}
translate S TwinCriteria3 {Es recomendable especificar "S" para al menos dos parmetros de "mismo lugar", "misma ronda" y "mismo ao".\nQuiere continuar y borrar dobles en todo caso?}
translate S TwinCriteriaConfirm {Scid: Confirmar parmetros para partidas dobles}
translate S TwinChangeTag "Cambiar las siguientes etiquetas de las:\n\n partidas"
translate S AllocRatingDescription "Este comando usar el actual fichero SpellCheck para aadir  puntuaciones ELO y partidas en esta base. En el caso de que un jugador no tenga puntuacin pero la tenga en el fichero  spellcheck, su puntuacin ser aadida."
translate S RatingOverride "Sobreescribir puntuaciones existentes no nulas?"
translate S AddRatings "Aadir puntuaciones a:"
translate S AddedRatings {Scid aadi $r puntuaciones Elo en $g partidas.}
translate S NewSubmenu "Nuevo submen"

# Comment editor:
translate S AnnotationSymbols  {Smbolos de anotacin:}
translate S Comment {Comentario:}
translate S InsertMark {Insertar marca}
translate S InsertMarkHelp {
Insertar/quitar marca: Selecciona color, tipo, casilla.
Insertar/quitar flecha: Botn derecho sobre dos casillas.
}

# Nag buttons in comment editor:
translate S GoodMove {Buena jugada}
translate S PoorMove {Mala jugada}
translate S ExcellentMove {Jugada excelente}
translate S Blunder {Error}
translate S InterestingMove {Jugada interesante}
translate S DubiousMove {Jugada dudosa}
translate S WhiteDecisiveAdvantage {Las blancas tienen decisiva ventaja}
translate S BlackDecisiveAdvantage {Las negras tienen decisiva ventaja}
translate S WhiteClearAdvantage {Las blancas tienen clara ventaja}
translate S BlackClearAdvantage {Las negras tienen clara ventaja}
translate S WhiteSlightAdvantage {Las blancas tienen ligera ventaja}
translate S BlackSlightAdvantage {Las negras tienen ligera ventaja}
translate S Equality {Igualdad}
translate S Unclear {Incierto}
translate S Diagram {Diagrama}

# Board search:
translate S BoardSearch {Tablero de bsqueda}
translate S FilterOperation {Operacin en filtro actual:}
translate S FilterAnd {Y (Restringir filtro)}
translate S FilterOr {O (Aadir al filtro)}

# Benigno
translate S FilterIgnore {IGNORAR (Reiniciar el filtro)}

translate S SearchType {Tipo de bsqueda}
translate S SearchBoardExact {Posicin exacta (todas las piezas en las mismas casillas)}
translate S SearchBoardPawns {Peones (igual material, todos los peones en las mismas casillas)}
translate S SearchBoardFiles {Columnas (igual material, todos los peones en las mismas columnas)}
translate S SearchBoardAny {Cualquiera (igual material, peones y piezas en cualquier parte)}
translate S SearchInRefDatabase {Bsqueda en la base de referencia}
translate S LookInVars {Mirar en variaciones}
translate S CQLLabel {Bsqueda CQL}
translate S CQLComments {Permite comentarios}
translate S CQLStrip {Quita comentarios de la partida}

# Material search:
translate S MaterialSearch {Bsqueda de material}
translate S Material {Material}
translate S Patterns {Patrones}
translate S Zero {Cero}
translate S Any {Cualquiera}
translate S CurrentBoard {Tablero actual}
translate S CommonEndings {Finales comunes}
translate S CommonPatterns {Patrones comunes}
translate S MaterialDiff {Diferencia de material}
translate S squares {casillas}
translate S SameColor {Igual color}
translate S OppColor {Color opuesto}
translate S Either {Cualquiera}
translate S MoveNumberRange {Rango de nmero de movimientos}
translate S MatchForAtLeast {Encuentro de al menos}
translate S HalfMoves {medios movimientos}

# Common endings in material search:
translate S EndingPawns {Finales de peones}
translate S EndingRookVsPawns {Torre vs. peon(es)}
translate S EndingRookPawnVsRook {Torre y 1 pen vs. torre}
translate S EndingRookPawnsVsRook {Torre y peon(es) vs. torre}
translate S EndingRooks {Finales de torre vs. torre}
translate S EndingRooksPassedA {Finales de torre vs. torre con pen pasado}
translate S EndingRooksDouble {Finales de dos torres}
translate S EndingBishops {Finales de alfil vs. alfil}
translate S EndingBishopVsKnight {Finales de alfil vs. caballo}
translate S EndingKnights {Finales de caballo vs. caballo}
translate S EndingQueens {Finales de dama vs. dama}
translate S EndingQueenPawnVsQueen {Dama y 1 pen vs. dama}
translate S BishopPairVsKnightPair {Medio juego de dos alfiles vs. dos caballos}

# Common patterns in material search:
translate S PatternWhiteIQP {PDA blanco}
translate S PatternWhiteIQPBreakE6 {PDA blanco: d4-d5 ruptura vs. e6}
translate S PatternWhiteIQPBreakC6 {PDA blanco: d4-d5 ruptura vs. c6}
translate S PatternBlackIQP {PDA negro}
translate S PatternWhiteBlackIQP {PDA blanco vs. PDA negro}
translate S PatternCoupleC3D4 {Pareja de peones aislados blancos c3+d4}
translate S PatternHangingC5D5 {Peones colgantes negros en c5 y d5}
translate S PatternMaroczy {Centro Maroczy (con peones en c4 y e4)}
translate S PatternRookSacC3 {Sacrificio de torre en c3}
translate S PatternKc1Kg8 {O-O-O vs. O-O (Rc1 vs. Rg8)}
translate S PatternKg1Kc8 {O-O vs. O-O-O (Rg1 vs. Rc8)}
translate S PatternLightFian {Fianchettos de casillas claras (Alfil-g2 vs. Alfil-b7)}
translate S PatternDarkFian {Fianchettos de casillas oscuras (Alfil-b2 vs. Alfil-g7)}
translate S PatternFourFian {Cuatro Fianchettos (Alfiles en b2,g2,b7,g7)}

# Game saving:
translate S Today {Hoy}
translate S ClassifyGame {Clasificar partida}

# Setup position:
translate S EmptyBoard {Tablero vaco}
translate S InitialBoard {Tablero inicial}
translate S SideToMove {Lado que mueve}
translate S MoveNumber {Movimiento nmero}
translate S Castling {Enroque}
translate S EnPassantFile {Columna al paso}
translate S ClearFen {Quitar FEN}
translate S PasteFen {Pegar FEN}
translate S SaveAndContinue {Salvar (grabar) y continuar}
translate S DiscardChangesAndContinue {Descartar Cambios}
translate S GoBack {Volver atrs}

# Replace move dialog:
translate S ReplaceMove {Reemplazar movimiento}
translate S AddNewVar {Aadir nueva variacin}
translate S NewMainLine {Nueva lnea principal}
translate S ReplaceMoveMessage {Ya existe un movimiento.

Por favor, seleccione su opcin
La opcin Reemplazar movimiento eliminar todos los movimientos posteriores}

# Make database read-only dialog:
translate S ReadOnlyDialog {Si haces que esta base de datos sea de slo lectura no se permitirn hacer cambios. No se podrn guardar o reemplazar partidas, y no se podrn alterar las seales de borrada. Cualquier ordenacin o clasificacin por ECO ser temporal.

Puedes hacer fcilmente escribible la base de datos otra vez cerrndola y abrindola.

Realmente quieres hacer que esta base de datos sea de slo lectura?}

# Exit dialog:
translate S ExitDialog {Realmente quieres salir de Scid?}
translate S ClearGameDialog {Esta partida ha sido alterada.\nDesea guardarla?}
translate S ExitUnsaved {La siguiente base de datos tiene cambios en partidas no guardadas. Si sales ahora se perdern estos cambios.}
translate S ChangeTextDialog {Activar el color del texto globalmente requiere reiniciar.}
translate S ChangeDockDialog {Cambiar el acoplado requiere reiniciar.}
translate S FontSelectDialog "Ejemplo de texto\nHaz doble clic arriva para cambiar la fuente, y selecciona 'ok'\nAaBbCcDdEeFfGgHhIiJjKkLlMm 0123456789. +=-"
translate S ExitNow {Salir ahora?}

# Import window:
translate S PasteCurrentGame {Pegar partida actual}
translate S ImportHelp1 \
  {Introducir o pegar una partida en formato PGN en el marco superior.}
translate S ImportHelp2 \
  {Cualquier error importando la partida ser mostrado aqu.}
translate S OverwriteExistingMoves {SobreEscribir movimientos existentes?}

# ECO Browser:
translate S ECOAllSections {todas las divisiones ECO}
translate S ECOSection {divisin ECO}
translate S ECOSummary {Resumen de}
translate S ECOFrequency {Frecuencia de los subcdigos para}

# Opening Report:
translate S OprepTitle {Informe de la apertura}
translate S OprepReport {Informe}
translate S OprepGenerated {Generado por}
translate S OprepStatsHist {Estadsticas e Historia}
translate S OprepStats {Estadsticas}
translate S OprepStatAll {Todas las partidas referidas}
translate S OprepStatBoth {Ambos con Elo}
translate S OprepStatSince {Desde}
translate S OprepOldest {Partidas ms antiguas}
translate S OprepNewest {Partidas ms nuevas}
translate S OprepPopular {Popularidad actual}
translate S OprepFreqAll {Frecuencia durante todos los aos: }
translate S OprepFreq1   {Desde el ltimo ao hasta hoy:     }
translate S OprepFreq5   {En los ltimos 5 aos hasta hoy:   }
translate S OprepFreq10  {En los ltimos 10 aos hasta hoy:  }
translate S OprepEvery {una vez cada %u partidas}
translate S OprepUp {sube un %u%s respecto al total de aos}
translate S OprepDown {baja un %u%s respecto al total de aos}
translate S OprepSame {no hay cambios respecto al total de aos}
translate S OprepMostFrequent {Jugadores ms frecuentes}
translate S OprepMostFrequentOpponents {Rivales ms frecuentes}
translate S OprepRatingsPerf {Elo y Rendimiento}
translate S OprepAvgPerf {Promedio de Elo y rendimiento}
translate S OprepWRating {Elo de las blancas}
translate S OprepBRating {Elo de las negras}
translate S OprepWPerf {Rendimiento de las blancas}
translate S OprepBPerf {Rendimiento de las negras}
translate S OprepHighRating {Partida con el mayor promedio de Elo}
translate S OprepTrends {Tendencias de Resultados}
translate S OprepResults {Resultado de duraciones y frecuencias}
translate S OprepLength {Duracin de la partida}
translate S OprepFrequency {Frecuencia}
translate S OprepWWins {Blancas ganan: }
translate S OprepBWins {Negras ganan:  }
translate S OprepDraws {Tablas:        }
translate S OprepWholeDB {en el conjunto de la base de datos}
translate S OprepShortest {Triunfos ms cortos}
translate S OprepMovesThemes {Movimientos y temas}
translate S OprepMoveOrders {Lneas de movimientos que alcanzan la posicin del informe}
translate S OprepMoveOrdersOne \
  {Slo hay una lnea de movimientos que alcanza esta posicin:}
translate S OprepMoveOrdersAll \
  {Hay %u lneas de movimiento que alcanzan esta posicin:}
translate S OprepMoveOrdersMany \
  {Hay %u lneas de movimiento que alcanzan esta posicin. Las %u ms comunes son:}
translate S OprepMovesFrom {Movimientos desde la posicin del informe}
translate S OprepMostFrequentEcoCodes {Aperturas ms frecuentes}
translate S OprepThemes {Temas posicionales}
translate S OprepThemeDescription {Frecuencia de los temas en las primeras %u jugadas de cada partida}
translate S OprepThemeSameCastling {Enroque al mismo lado}
translate S OprepThemeOppCastling {Enroque en lados opuestos}
translate S OprepThemeNoCastling {Ambos reyes no enrocados}
translate S OprepThemeKPawnStorm {Avanzada de los peones del rey}
translate S OprepThemeQueenswap {Damas intercambiadas}
translate S OprepThemeWIQP {Pen de dama aislado de las blancas}
translate S OprepThemeBIQP {Pen de dama aislado de las negras}
translate S OprepThemeWP567 {Peones blancos en 5/6/7 fila}
translate S OprepThemeBP234 {Peones negros en 2/3/4 fila}
translate S OprepThemeOpenCDE {Columnas c/d/e abiertas}
translate S OprepTheme1BishopPair {Un lado tiene los dos alfiles}
translate S OprepEndgames {Finales}
translate S OprepReportGames {Informe de partidas}
translate S OprepAllGames {Todas las partidas}
translate S OprepEndClass {Tipos de finales segn la ltima posicin de las partidas}
translate S OprepTheoryTable {Tabla Terica}
translate S OprepTableComment {Generado a partir de las %u partidas con mejor Elo.}
translate S OprepExtraMoves {Anotacin extra de movimientos en la tabla terica}
translate S OprepMaxTableGames {Mximas partidas en la tabla terica}
translate S OprepMaxGames {Nmero mximo de juegos para estadsticas}
translate S OprepViewHTML {Ver HTML}
translate S OprepViewLaTeX {Ver LaTeX}

# Player Report:
translate S PReportTitle {Informe del jugador}
translate S PReportColorWhite {con las piezas blancas}
translate S PReportColorBlack {con las piezas negras}
translate S PReportBeginning {Empezando con}
translate S PReportMoves {%s despus}
translate S PReportOpenings {Aperturas}
translate S PReportClipbase {Vaciar portapapeles y copiar las partidas}

# Piece Tracker window:
translate S TrackerSelectSingle {El botn izquierdo selecciona esta pieza.}
translate S TrackerSelectPair {El botn izquierdo selecciona esta pieza; el botn derecho tambin selecciona su hermana.}
translate S TrackerSelectPawn {El botn izquierdo selecciona este pen; el botn derecho selecciona los 8 peones.}
translate S TrackerStat {Estadstica}
translate S TrackerGames {% de partidas con movimiento a esta casilla}
translate S TrackerTime {% de tiempo en esta casilla}
translate S TrackerMoves {Movimientos}
translate S TrackerMovesStart {Escribe el nmero del movimiento desde donde debe empezar el rastreo.}
translate S TrackerMovesStop {Escribe el nmero del movimiento donde debe parar el rastreo.}

# Game selection dialogs:
translate S SelectAllGames {Todas las partidas de la base de datos}
translate S SelectFilterGames {Slo las partidas filtradas}
translate S SelectTournamentGames {Slo las partidas del actual torneo}
translate S SelectOlderGames {Slo partidas antiguas}

# Delete Twins window:
translate S TwinsNote {Para ser dobles, dos partidas deben de tener al menos los mismos dos jugadores, y los criterios que fijes debajo. Cuando un par de dobles es encontrado, la partida ms corta es borrada. Sugerencia: es mejor hacer la correccin ortogrfica de la base de datos antes de iniciar el borrado de dobles, porque esto mejora su deteccin.}
translate S TwinsCriteria {Criterios: Las partidas dobles deben tener...}
translate S TwinsWhich {Partidas a examinar}
translate S TwinsColors {Jugadores con igual color?}
translate S TwinsEvent {Mismo evento?}
translate S TwinsSite {Mismo sitio?}
translate S TwinsRound {Misma ronda?}
translate S TwinsYear {Mismo ao?}
translate S TwinsMonth {Mismo mes?}
translate S TwinsDay {Mismo da?}
translate S TwinsResult {Mismo resultado?}
translate S TwinsECO {Mismo cdigo ECO?}
translate S TwinsMoves {Mismos movimientos?}
translate S TwinsPlayers {Comparando nombres de jugadores:}
translate S TwinsPlayersExact {Encuentro exacto}
translate S TwinsPlayersPrefix {Slo las primeras 4 letras}
translate S TwinsWhen {Cuando se borren partidas dobles}
translate S TwinsSkipShort {Ignorar todas las partidas con menos de 5 movimientos?}
translate S TwinsUndelete {Quitar marcas de borrado primero?}
translate S TwinsSetFilter {Poner filtro a todas las partidas borradas?}
translate S TwinsComments {Saltar siempre partidas con comentarios?}
translate S TwinsVars {Saltar siempre partidas con variaciones?}
translate S TwinsDeleteWhich {Qu partida borrar:}
translate S TwinsDeleteShorter {Partida ms corta}
translate S TwinsDeleteOlder {Nmero de partida menor}
translate S TwinsDeleteNewer {Nmero de partida mayor}
translate S TwinsDelete {Borrar partidas}

# Name editor window:
translate S NameEditType {Tipo de nombre a editar}
translate S NameEditSelect {Partidas a editar}
translate S NameEditReplace {Reemplazar}
translate S NameEditWith {Con}
translate S NameEditMatches {Partidas: Presionar Ctrl+1 a Ctrl+9 para seleccionarla}
translate S MatchPattern {Patrn de coincidencia}

# Classify window:
translate S Classify {Clasificar}
translate S ClassifyWhich {Clasificar por cdigos ECO}
translate S ClassifyAll {Todas las partidas (sobreescribir cdigo ECO)}
translate S ClassifyYear {Todas las partidas jugadas en el ltimo ao}
translate S ClassifyMonth {Todas las partidas jugadas en el ltimo mes}
translate S ClassifyNew {Slo las partidas todava sin cdigo ECO}
translate S ClassifyCodes {Cdigo ECO a usar}
translate S ClassifyBasic {Slo cdigo bsico ("B12", ...)}
translate S ClassifyExtended {Extensiones Scid ("B12j", ...)}

# Compaction:
translate S NameFile {Archivo de nombres}
translate S GameFile {Archivo de partidas}
translate S Names {Nombres}
translate S Unused {No usado}
translate S SizeKb {Tamao (kb)}
translate S CurrentState {Estado actual}
translate S AfterCompaction {Despus de la compactacin}
translate S CompactNames {Compactar archivo de nombres}
translate S CompactGames {Compactar archivo de partidas}
translate S NoUnusedNames "No hay nombres sin usar, por tanto, el fichero de nombres est ya totalmente compactado."
translate S NoUnusedGames "El fichero ya est totalmente compactado."
translate S NameFileCompacted {El fichero de nombre para la base de datos "[file tail [sc_base filename]]" fue compactado.}
translate S GameFileCompacted {El fichero de partidas para la base de datos "[file tail [sc_base filename]]" fue compactado.}

# Sorting:
translate S SortCriteria {Criterio}
translate S AddCriteria {Aadir criterio}
translate S CommonSorts {Ordenaciones comunes}
translate S Sort {Ordenar}

# Exporting:
translate S AddToExistingFile {Aadir partidas a un archivo existente?}
translate S ExportComments {Exportar comentarios?}
translate S ExportVariations {Exportar variaciones?}
translate S IndentComments {Sangrar comentarios?}
translate S IndentVariations {Sangrar variaciones?}
translate S InsertNewlines {Insertar saltos de lnea cada 80 caracteres?}
translate S ExportColumnStyle {Estilo de columna (un movimiento por lnea)?}
translate S ExportSymbolStyle {Estilo de anotacin simblico:}
translate S ExportStripMarks {Quitar marca de cdigos de casilla/flecha de los comentarios?}

translate S ExportFlags {Exportar Marcas de Scid}

# Goto game/move dialogs:
translate S LoadGameNumber {Entra el nmero de la partida a cargar:}
translate S GotoMoveNumber {Ir al movimiento nmero:}

# Copy games dialog:
translate S CopyGames {Copiar partidas}
translate S CopyConfirm {
 Realmente deseas copiar las [::utils::thousands $nGamesToCopy] partidas filtradas
 de la base de datos "$fromName"
 a la base de datos "$targetName"?
}
translate S CopyErr {No se pueden copiar las partidas}
translate S CopyErrSource {la base de datos fuente}
translate S CopyErrTarget {la base de datos de destino}
translate S CopyErrNoGames {no tiene partidas en su filtro}
translate S CopyErrReadOnly {es slo de lectura}
translate S CopyErrNotOpen {no est abierta}

# Colors:
translate S LightSquares {Casillas claras}
translate S DarkSquares {Casillas oscuras}
translate S SelectedSquares {Casillas seleccionadas}
translate S SelectedOutline {Caja seleccionada}
translate S SuggestedSquares {Sugeridas}
translate S Grid {Cuadrcula}
translate S Previous {Eleccin}
translate S WhitePieces {Piezas blancas}
translate S BlackPieces {Piezas negras}
translate S WhiteBorder {Borde blancas}
translate S BlackBorder {Borde negras}
translate S ArrowMain   {Flecha lnea principal}
translate S ArrowVar    {Flechas de variaciones}
translate S ShowArrows  {Mostrar flechas}

# Novelty window:
translate S FindNovelty {Encontrar novedad}
translate S Novelty {Novedad}
translate S NoveltyInterrupt {Busqueda de novedades interrumpida}
translate S NoveltyNone {Ninguna novedad encontrada para esta partida}
translate S NoveltyHelp {
Scid encontrar el primer movimiento de la actual partida que alcanza una posicin no encontrada en la base de datos seleccionada o en el libro de aperturas ECO.
}

# Sounds configuration:
translate S SoundsFolder {Directorio de los archivos de sonido}
translate S SoundsFolderHelp {El directorio debe contener los archivos King.wav, a.wav, 1.wav, etc}
translate S SoundsAnnounceOptions {Opciones de anunciamiento de movimientos}
translate S SoundsAnnounceNew {Anunciar nuevos movimientos cuando sean hechos}
translate S SoundsAnnounceForward {Anunciar movimientos cuando avancemos un movimiento}
translate S SoundsAnnounceBack {Anunciar movimiento cuando rectifiquemos o retrocedamos una jugada}

# Upgrading databases:
translate S Upgrading {Actualizacin}
translate S ConfirmOpenNew {
Este es un formato de base de datos antiguo (Scid 2) que no puede ser abierto con Scid 3, pero ya se ha creado una versin de formato nuevo (Scid 3).

Quieres abrir la versin de formato nuevo de la base de datos?
}
translate S ConfirmUpgrade {
Esta es una base de datos en un formato antiguo (Scid 2). Se debe crear una versin de formato nuevo de base de datos antes de poder ser usada en Scid 3.

La actualizacin crear una nueva versin de la base de datos; esta no corregir o borrar los archivos originales.

Esto puede tomar un tiempo, pero slo es necesario hacerlo una vez. Puedes cancelar si toma demasiado tiempo.

Quieres actualizar esta base de datos ahora?
}

# Recent files options:
translate S RecentFilesMenu {Nmero de archivos recientes en el men Archivo}
translate S RecentFilesExtra {Nmero de archivos recientes en submen extra}

# My Player Names options:
translate S MyPlayerNamesDescription {
Escriba una lista de nombres de jugadores preferidos, un nombre por cada lnea. Estn permitidos los comodines (por ejemplo "?" para un slo caracter, "*" para varios caracteres).

Cada vez que carge una partida con un jugador de la lista se girar el tablero, si fuese necesario, para ver la partida desde la perspectiva del jugador.
}

# coach
translate S showblunderexists {Mostrar metedura de pata}
translate S showblundervalue {Mostrar valor de la metedura de pata}
translate S showscore {Mostrar marcador}
translate S coachgame {Entrenador}
translate S configurecoachgame {Configurar entrenador}
translate S configuregame {Configuracin de partida UCI}
translate S Phalanxengine {Motor Phalanx}
translate S Coachengine {Motor entrenador}
translate S difficulty {Dificultad}
translate S hard {Duro}
translate S easy {Fcil}
translate S Playwith {Juega con}
translate S white {blancas}
translate S black {negras}
translate S both {ambos}
translate S Play {Jugar}
translate S Noblunder {Sin errores}
translate S blunder {Meteduras de pata}
translate S Noinfo {-- Sin informacin --}
translate S moveblunderthreshold {El movimiento es una metedura de pata si la prdida de puntuacin es mayor que }
translate S limitanalysis {Tiempo lmite para anlisis del motor}
translate S seconds {segundos}
translate S Abort {Abortar}
translate S Quit {Salir}
translate S Resume {Reanudar}
translate S Restart {Reiniciar}
translate S OutOfOpening {Fuera de apertura}
translate S NotFollowedLine {T no sigues la lnea}
translate S DoYouWantContinue {Quieres continuar?}
translate S CoachIsWatching {Entrenador}
translate S Ponder {Pensar siempre (el motor)}
translate S LimitELO {Limitar fuerza ELO}
translate S DubiousMovePlayedTakeBack {Movimiento dudoso, quieres rectificar?}
translate S WeakMovePlayedTakeBack {Movimiento flojo, quieres rectificar ?}
translate S BadMovePlayedTakeBack {Movimiento malo, quieres rectificar ?}
translate S Iresign {Yo abandono}
translate S yourmoveisnotgood {tu movimiento no es bueno}
translate S EndOfVar {Fin de la variante}
translate S Openingtrainer {Entrenador de aperturas}
translate S DisplayCM {Muestra posibles movimientos}
translate S DisplayCMValue {Muestra valor de posibles movimientos}
translate S DisplayOpeningStats {Muestra estadsticas}
translate S ShowReport {Muestra informe}
translate S NumberOfGoodMovesPlayed {buenos movimientos jugados}
translate S NumberOfDubiousMovesPlayed {dudosos momientos jugados}
translate S NumberOfTimesPositionEncountered {veces encontrada la posicin}
translate S PlayerBestMove  {Permite nicamente movimientos mejores}
translate S OpponentBestMove {Oponente juega mejores movimientos}
translate S OnlyFlaggedLines {Slo lneas marcadas}
translate S resetStats {Reinicia estadsticas}
translate S Movesloaded {Movimientos cargados}
translate S PositionsNotPlayed {Posiciones no jugadas}
translate S PositionsPlayed {Posiciones jugadas}
translate S Success {xitos}
translate S DubiousMoves {Movimientos dudosos}
translate S ConfigureTactics {Configurar tctica}
translate S ResetScores {Reiniciar marcadores (puntuaciones)}
translate S LoadingBase {Cargando base}
translate S Tactics {Tcticas}
translate S ShowSolution {Mostrar solucin}
translate S Next {Siguiente}
translate S ResettingScore {Reiniciando marcador}
translate S LoadingGame {Cargando partida}
translate S MateFound {Mate encontrado}
translate S BestSolutionNotFound {NO fue encontrada la mejor solucin!}
translate S MateNotFound {Mate no encontrado}
translate S ShorterMateExists {Esiste un mate ms corto}
translate S ScorePlayed {Marcador jugado}
translate S Expected {Esperado}
translate S ChooseTrainingBase {Elegir base de entrenamiento}
translate S Thinking {Pensando}
translate S AnalyzeDone {Anlisis hecho}
translate S WinWonGame {Gana la partida ganada}
translate S Lines {Lneas}
translate S ConfigureUCIengine {Configurar motor}
translate S SpecificOpening {Apertura especfica}
translate S ImportECO {Importar ECO}
translate S StartNewGame {Empezar partida nueva}
translate S FixedLevel {Nivel fijado}
translate S Opening {Abriendo}
translate S RandomLevel {Nivel aleatorio}
translate S StartFromCurrentPosition {Empezar desde la posicin actual}
translate S FixedDepth {Profundidad fija}
translate S Nodes {Nodos}
translate S Depth {Profundidad}
translate S Time {Tiempo}
translate S Auto {Auto}
translate S Score {Puntuacin}
translate S {Score Combo} {Selector de puntuacin}
translate S {Time Combo} {Selector de tiempo}
translate S SecondsPerMove {Segundos por movimiento}
translate S DepthPerMove {Profundidad por movimiento}
translate S MoveControl {Movimiento del control}
translate S TimeLabel {Tiempo por movimiento}
translate S AddVars {Aadir las variaciones}
translate S AddScores {Aadir valoracin o puntuacin}
translate S Engine {Motor}
translate S TimeMode {Modo de tiempo}
translate S TimeBonus {Tiempo + bonus}
translate S TimeMin {min}
translate S TimeSec {seg}
translate S AllExercisesDone {Todos los ejercicio hechos}
translate S MoveOutOfBook {Movimiento fuera del libro}
translate S LastBookMove {ltimo movimiento del libro}
translate S AnnotateSeveralGames {Anotar las partidas}
translate S FindOpeningErrors {Solo errores de apertura en los primeros}
translate S MarkTacticalExercises {Marca ejercicios tcticos}
translate S UseBook {Usar libro de aperturas (Book)}
translate S MultiPV {Variantes mltiples}
translate S Hash {Memoria Hash}
translate S OwnBook {Usar libro (book) del motor}
translate S BookFile {Libro de aperturas}
translate S AnnotateVariations {Procesar variantes}
translate S ShortAnnotations {Anotaciones cortas}
translate S addAnnotatorTag {Aadir etiqueta de anotador}
translate S AddScoreToShortAnnotations {Aadir puntuacin para anotaciones cortas}
translate S Export {Exportar}
translate S BookPartiallyLoaded {Libro parcialmente cargado}
translate S AddLine {Aadir lnea}
translate S RemLine {Eliminar lnea}
translate S Calvar {Clculo de variantes}
translate S ConfigureCalvar {Configuracin}
# Opening names used in tacgame.tcl
translate S Reti {Apertura Reti}
translate S English {Apertura inglesa}
translate S d4Nf6Miscellaneous {1.d4 Cf6 variadas}
translate S Trompowsky {Apertura Trompowsky}
translate S Budapest {Gambito Budapest}
translate S OldIndian {Defensa India Antigua}
translate S BenkoGambit {Gambinko}
translate S ModernBenoni {Defensa Benoni Moderna}
translate S DutchDefence {Defensa Holandesa}
translate S Scandinavian {Defensa Escandinava}
translate S AlekhineDefence {Defensa Alekhine}
translate S Pirc {Defensa Pirc}
translate S CaroKann {Defensa Caro-Kann}
translate S CaroKannAdvance {Defensa Caro-Kann, Variante del Avance}
translate S Sicilian {Defensa Siciliana}
translate S SicilianAlapin {Defensa Siciliana, Variante Alapin}
translate S SicilianClosed {Defensa Siciliana, Variante Cerrada}
translate S SicilianRauzer {Defensa Siciliana, Variante Rauzer}
translate S SicilianDragon {Defensa Siciliana, Variante del Dragon}
translate S SicilianScheveningen {Defensa Siciliana, Variante Scheveningen}
translate S SicilianNajdorf {Defensa Siciliana, Variante Najdorf}
translate S OpenGame {Apertura Abierta}
translate S Vienna {Apertura Vienesa}
translate S KingsGambit {Gambito de Rey}
translate S RussianGame {Partida Rusa}
translate S ItalianTwoKnights {Apertura Italiana, Variante de los Dos Caballos}
translate S Spanish {Apertura Espaola}
translate S SpanishExchange {Apertura Espaola, Variante del cambio}
translate S SpanishOpen {Apertura Espaola}
translate S SpanishClosed {Apertura Espaola, Variante Cerrada}
translate S FrenchDefence {Defensa Francesa}
translate S FrenchAdvance {Defensa Francesa, Variante del Avance}
translate S FrenchTarrasch {Defensa Francesa, Variante Tarrasch}
translate S FrenchWinawer {Defensa Francesa, Variante Winawer}
translate S FrenchExchange {Defensa Francesa, Variante del cambio}
translate S QueensPawn {Apertura de Pen de Dama}
translate S Slav {Defensa Eslava}
translate S QGA {Gambito de Dama Aceptado}
translate S QGD {Gambito de Dama Declinado}
translate S QGDExchange {Gambito de Dama Declinado, Variante del Cambio}
translate S SemiSlav {Defensa Semi-Eslava del Gambito de Dama Declinado}
translate S QGDwithBg5 {Gambito de Dama Declinado con Ag5}
translate S QGDOrthodox {Gambido de Dama Declinado,  Defensa Ortodoxa}
translate S Grunfeld {Defensa Grnfeld}
translate S GrunfeldExchange {Variante del cambio de la Defensa Grnfeld }
translate S GrunfeldRussian {Variante Rusa de la Defensa Grnfeld}
translate S Catalan {Catalana}
translate S CatalanOpen {Apertura Catalana}
translate S CatalanClosed {Apertura Catalana, Variante Cerrada}
translate S QueensIndian {Defensa India de Dama}
translate S NimzoIndian {Apertura Nimzo-India}
translate S NimzoIndianClassical {Apertura Nimzo-India Clsica}
translate S NimzoIndianRubinstein {Variante Rubinstein de la Nimzo-India}
translate S KingsIndian {India de Rey}
translate S KingsIndianSamisch {Ataque Smish de la India de Rey}
translate S KingsIndianMainLine {Lnea Principal India de Rey}

#fics
translate S ConfigureFics {Configurar FICS}
translate S FICSLogin {Autentificar}
translate S FICSGuest {Autentificacin como invitado}
translate S FICSServerPort {Puerto del servidor}
translate S FICSServerAddress {Direccin IP}
translate S FICSRefresh {Refrescar}
translate S FICSTimeseal {Timeseal}
translate S FICSTimesealPort {Puerto Timeseal}
translate S FICSSilence {Silencio}
translate S FICSOffers {Ofertas}
translate S FICSMakeOffer {Hacer oferta}
translate S FICSGames {Partidas}
translate S FICSFindOpponent {Buscar oponente}
translate S FICSTakeback {Retrocede}
translate S FICSTakeback2 {Retrocede 2}
translate S FICSInitTime {Tiempo inicial (min)}
translate S FICSIncrement {Incremento (seg)}
translate S FICSRatedGame {Partida valorada}
translate S FICSAutoColour {automtico}
translate S FICSManualConfirm {confirma manualmente}
translate S FICSFilterFormula {Filtrar con frmula}
translate S FICSIssueSeek {Panel de retos}
translate S FICSAccept {aceptar}
translate S FICSDecline {rechazar}
translate S FICSColour {Color}
translate S FICSSend {enviar}
translate S FICSConnect {Conectar}
translate S FICSShouts {Gritos}
translate S FICSTells {Decir}
translate S FICSOpponent {Informacin del oponente}
translate S FICSInfo {Informacin}
translate S FICSDraw {Ofrecer tablas}
translate S FICSRematch {Revancha}
translate S FICSQuit {Salir}
translate S FICSCensor {Censurar}

# Correspondence Chess Dialogs:
translate S CCDlgConfigureWindowTitle {Configurar ajedrez por correo}
translate S CCDlgCGeneraloptions {Opciones generales}
translate S CCDlgDefaultDB {Base por defecto:}
translate S CCDlgInbox {Entrante (Carpeta):}
translate S CCDlgOutbox {Saliente (carpeta):}
translate S CCDlgXfcc {Configuracin Xfcc:}
translate S CCDlgExternalProtocol {Protocolo externo (p.ej. Xfcc)}
translate S CCDlgFetchTool {Herramienta de traer:}
translate S CCDlgSendTool {Herramienta de envo:}
translate S CCDlgEmailCommunication {Comunicacin email}
translate S CCDlgMailPrg {Programa de correo:}
translate S CCDlgBCCAddr {(B)CC Direccin:}
translate S CCDlgMailerMode {Modo:}
translate S CCDlgThunderbirdEg {p.e. Thunderbird, Mozilla Mail, Icedove...}
translate S CCDlgMailUrlEg {p.e. Evolution}
translate S CCDlgClawsEg {p.e. Sylpheed Claws}
translate S CCDlgmailxEg {p.e. mailx, mutt, nail...}
translate S CCDlgAttachementPar {Parmetro Adjunto (Attachment):}
translate S CCDlgInternalXfcc {Usar soporte interno Xfcc}
translate S CCDlgConfirmXfcc {Confirmar jugadas}
translate S CCDlgSubjectPar {Parmetro Sujeto (Subject):}
translate S CCDlgDeleteBoxes {Vaciar Entrante/Saliente}
translate S CCDlgDeleteBoxesText {Quieres realmente vaciar tus carpetas Entrante y Saliente para Ajedrez por correspondencia? Esto requiere una nueva sincronizacin para mostrar el estado ltimo de tus partidas}
translate S CCDlgConfirmMove {Confirmar jugada}
translate S CCDlgConfirmMoveText {Si t confirmas, la siguiente jugada y comentario ser enviado al servidor:}
translate S CCDlgDBGameToLong {Lnea principal inconsistente}
translate S CCDlgDBGameToLongError {La lnea principal en tu base es ms larga que de la partida en la bandeja de entrada. Si la bandeja de entrada contiene la partida actual, algunos movimientos fueron aadidos a la lnea principal en la base errneamente.\nEn este caso acorte la lnea principal a la (max) jugada\n}
translate S CCDlgStartEmail {Empezar nueva partida por email}
translate S CCDlgYourName {Tu nombre:}
translate S CCDlgYourMail {Tu direccin email:}
translate S CCDlgOpponentName {Nombre de oponente:}
translate S CCDlgOpponentMail {Direccin email de oponente:}
translate S CCDlgGameID {Partida ID (nico):}
translate S CCDlgTitNoOutbox {Scid: Salida del correo de ajedrez}
translate S CCDlgTitNoInbox {Scid: Entrada del correo de ajedrez}
translate S CCDlgTitNoGames {Scid: No hay partidas de ajedrez por correo}
translate S CCErrInboxDir {Carpeta de entrada del correo de ajedrez (Entrante):}
translate S CCErrOutboxDir {Carpeta de salida del correo de ajedrez (Saliente):}
translate S CCErrDirNotUsable {No existe o no est accesible!\nPor favor, compruebe y corrija los parmetros.}
translate S CCErrNoGames {No contiene ninguna partida!\nPor favor, trigala primero.}
translate S CCDlgTitNoCCDB {Scid: No es una base de ajedrez por correo}
translate S CCErrNoCCDB {No hay una base del tipo 'Correo' abierta. Por favor, abra una antes de usar funciones de ajedrez por correo.}
translate S CCFetchBtn {Traer partidas desde el servidor y procesar correo entrante}
translate S CCPrevBtn {Ir a partida anterior}
translate S CCNextBtn {Ir a partida siguiente}
translate S CCSendBtn {Enviar movimiento}
translate S CCEmptyBtn {Correos entrante y saliente vacos}
translate S CCHelpBtn {Ayuda en iconos e indicadores de estatus. \n Para ayuda general, pulse F1}
translate S CCDlgServerName {Nombre del servidor}
translate S CCDlgLoginName  {Nombre de usuario}
translate S CCDlgPassword   {Contrasea}
translate S CCDlgURL        {Xfcc-URL}
translate S CCDlgRatingType {Tipo de puntuacin (Rating)}
translate S CCDlgDuplicateGame {El ID de la partida no es nico}
translate S CCDlgDuplicateGameError {Esta partida existe ms de una vez en tu base. Por favor, borra todos los duplicados y compacta tu fichero de partidas (Fichero/Mantenimiento/Compactar base de datos).}
translate S CCDlgSortOption {Ordenando:}
translate S CCDlgListOnlyOwnMove {Slo partidas que tienen el movimiento}
translate S CCOrderClassicTxt {Lugar, Evento, Ronda, Resultado, Blancas, Negras}
translate S CCOrderMyTimeTxt {Mi reloj}
translate S CCOrderTimePerMoveTxt {Tiempo por movimiento falta el prximo control de tiempo}
translate S CCOrderStartDate {Empezar fecha}
translate S CCOrderOppTimeTxt {Reloj de los oponentes}
translate S CCDlgConfigRelay {Configurar observaciones ICCF}
translate S CCDlgConfigRelayHelp {Ir a las partidas de la pgina en http://www.iccf-webchess.com y mostrar la partida a ser observada. Si ves el tablero de ajedrez copia la URL desde tu explorador a la lista. !Una sola URL por lnea!\nExample: http://www.iccf-webchess.com/MakeAMove.aspx?id=266452}

# Connect Hardware dialoges
translate S ExtHWConfigConnection {Configurar tablero externo}
translate S ExtHWPort {Puerto}
translate S ExtHWEngineCmd {Comando del motor}
translate S ExtHWEngineParam {Parmetro del motor}
translate S ExtHWShowButton {Mostrar botn}
translate S ExtHWHardware {Tablero}
translate S ExtHWNovag {Novag Citrine}
translate S ExtHWInputEngine {Tablero (Ext)}
translate S ExtHWNoBoard {Sin tablero}

# Input Engine dialogs
translate S IEConsole {Consola tablero (Ext)}
translate S IESending {Movimientos enviados por}
translate S IESynchronise {Sincronizar}
translate S IERotate  {Rotar}
translate S IEUnableToStart {Imposible empezar tablero (Ext):}

# Calculation of Variations
translate S DoneWithPosition {Hecho con la posicin}
translate S Board {Tablero}
translate S showGameInfo {Mostrar informacin de la partida}
translate S autoResizeBoard {Tamao automtico del tablero}
translate S DockTop {Mover arriba}
translate S DockBottom {Mover abajo}
translate S DockLeft {Mover a la izquierda}
translate S DockRight {Mover a la derecha}
translate S Undock {Ventana flotante}
translate S ChangeIcon {Cambiar icono}
translate S More {Ms}

# Drag & Drop
translate S CannotOpenUri {No se puede abrir la siguiente URI:}
translate S InvalidUri {Descartar contenido no es una lista URI vlida.}
translate S UriRejected	{Los siguientes archivos fueron rechazados:}
translate S UriRejectedDetail {Slo pueden manejarse los tipos de archivo listados:}
translate S EmptyUriList {Descartar. Contenido est vaco.}
translate S SelectionOwnerDidntRespond {Tiempo excedido durante la operacin: el propietario de la seleccin no respondi.}
translate S PasteAnal {Pegar anlisis}
translate S SortOpcodes {Ordenar cdigos de operacin}
translate S AddPosition {Aadir posicin}
translate S FindPos {Encuentra la posicin de juego ms profunda}
translate S AnalPosition {Analizar posiciones}
translate S StripOpcodes {Separa cdigos de operacin}
translate S NoMoves {No hay movimientos desde esta posicin}
translate S CountBestMoves {Contar los mejores movimientos}

}
# end of spanish.tcl
